@@ -38,8 +38,9 @@ def version_callback(value: bool):
         raise typer.Exit()
 
 
-@app.callback()
+@app.callback(invoke_without_command=True)
 def main(
+    ctx: typer.Context,
     version: Optional[bool] = typer.Option(None, "--version", "-v", callback=version_callback, 
                                          help="Показать версию"),
     endpoint: Optional[str] = typer.Option(None, "--endpoint", "-e", 
@@ -56,6 +57,36 @@ def main(
     
     if profile:
         config.set_default_profile(profile)
+    
+    # Если команда не указана, пытаемся запустить интерактивный режим
+    if ctx.invoked_subcommand is None:
+        auth_manager = AuthManager(config)
+        
+        # Проверяем авторизацию
+        if not auth_manager.is_authenticated(profile):
+            console.print("👋 [blue]Добро пожаловать в DurusAI CLI![/blue]")
+            console.print("❌ Вы не авторизованы", style="red")
+            console.print("💡 Используйте [green]durusai login[/green] для входа", style="yellow")
+            console.print()
+            console.print("📚 Доступные команды:")
+            console.print("   [green]durusai login[/green]     - войти в систему")
+            console.print("   [green]durusai --help[/green]    - показать справку")
+            raise typer.Exit(1)
+        
+        # Пользователь авторизован - запускаем интерактивный режим
+        console.print("🚀 [blue]Запуск интерактивного режима...[/blue]")
+        console.print("💡 Используйте [green]/help[/green] для справки или [green]/quit[/green] для выхода")
+        console.print()
+        
+        # Получаем аутентифицированный клиент
+        client = auth_manager.get_authenticated_client(profile)
+        if not client:
+            console.print("❌ Не удалось создать API клиент", style="red")
+            raise typer.Exit(1)
+        
+        # Запускаем интерактивный режим
+        interactive_mode = InteractiveMode(client, config, None)
+        interactive_mode.run()
 
 
 @app.command()
@@ -192,7 +223,7 @@ def query(
 
 
 @app.command()
-def chat(
+def interactive(
     profile: Optional[str] = typer.Option(None, "--profile", "-p", 
                                         help="Профиль пользователя"),
     model: Optional[str] = typer.Option(None, "--model", "-m", 
@@ -219,6 +250,19 @@ def chat(
     interactive_mode.run()
 
 
+@app.command()
+def chat(
+    profile: Optional[str] = typer.Option(None, "--profile", "-p", 
+                                        help="Профиль пользователя"),
+    model: Optional[str] = typer.Option(None, "--model", "-m", 
+                                      help="Модель AI для использования"),
+):
+    """💬 Интерактивный режим чата с AI (alias для interactive)"""
+    # Просто вызываем interactive команду
+    ctx = typer.Context(chat)
+    ctx.invoke(interactive, profile=profile, model=model)
+
+
 @app.command()
 def models(
     profile: Optional[str] = typer.Option(None, "--profile", "-p", 
